/*
 * Copyright 2008 Alin Dreghiciu.
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ops4j.pax.web.extender.whiteboard.internal.tracker;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.ops4j.pax.web.extender.whiteboard.JspMapping;
import org.ops4j.pax.web.extender.whiteboard.internal.ExtenderContext;
import org.ops4j.pax.web.extender.whiteboard.internal.element.JspWebElement;

/**
 * Tracks {@link JspMapping}.
 *
 * @author Alin Dreghiciu
 * @since 0.4.0, March 14, 2008
 */
public class JspMappingTracker
    extends AbstractTracker<JspMapping, JspWebElement>
{

    /**
     * Constructor.
     *
     * @param extenderContext extender context; cannot be null
     * @param bundleContext   extender bundle context; cannot be null
     */
    public JspMappingTracker( final ExtenderContext extenderContext,
                              final BundleContext bundleContext )
    {
        super(
            extenderContext,
            bundleContext,
            JspMapping.class
        );
    }

    /**
     * @see AbstractTracker#createWebElement(ServiceReference, Object)
     */
    @Override
    JspWebElement createWebElement( final ServiceReference serviceReference,
                                    final JspMapping published )
    {
        return new JspWebElement( published );
    }

}